#!/bin/bash
### BEGIN INIT INFO
# Provides:          ecatp-server 
# Required-Start:    $local_fs $network $named $time $syslog
# Required-Stop:     $local_fs $network $named $time $syslog
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Description:       Service ecatp server.
### END INIT INFO

#set -x

PATH="/sbin:/bin:/usr/sbin:/usr/bin" #Ne pas toucher

DAEMON="gesa_server"
DAEMON_DIR="/usr/local/ecatp"
DAEMON_OPTS="-f /etc/esia/ecatp.conf"
DAEMON_NAME="ecatp-server"

DAEMON_EXEC="$DAEMON_DIR/$DAEMON"

RUNAS=root

PIDFILE=/var/run/$DAEMON_NAME.pid
LOGFILE=/var/log/esia/$DAEMON_NAME.log
LOCKFILE=/var/lock/$DAEMON_NAME.lock

NB_LOOP=9
LOGFILE=/var/log/esia/ecatp-server.log

test -x "$DAEMON_EXEC" || exit 1

. /lib/lsb/init-functions

#
# Function that execute logrotate
#
do_logrotate()
{
        FILE=$LOGFILE
        for i in `seq $NB_LOOP -1 1`
        do
                let "j=i-1"
                if [ -f "$FILE$j" ]; then
                        mv "$FILE$j" "$FILE$i"
                fi
        done
        #cp --preserve $FILE ${FILE}1
        if [ -f $FILE ]; then
                mv $FILE ${FILE}1
        fi
}

testlock(){
        grep 1 $LOCKFILE
        if [ $? -eq 1 ]
        then
                return 1
        else
                return 0
        fi
}

lock(){
        testlock && sleep 3             #Si verrou on attends.
        testlock && unlock && exit 1    #Si toujours verrou, on débloque avant de quitter afin d'inviter tous risque de verrou bloqué indéfiniment
        echo 1 > $LOCKFILE
}

unlock(){
        echo 0 > $LOCKFILE
}

d_start() {
        lock
	do_logrotate
        log_daemon_msg "Starting system $DAEMON_NAME daemon"
        start-stop-daemon --start --no-close --background --quiet --pidfile $PIDFILE --make-pidfile --exec $DAEMON_EXEC -- $DAEMON_OPTS > $LOGFILE 2>&1
        sleep 2 #Sans le sleep on détecte ci-dessous que le process est lancé même quand il n'arrive pas à se connecter
        status_of_proc -p "$PIDFILE" "$DAEMON_EXEC" "$DAEMON_NAME"
        RET=$?
        log_end_msg $RET
        unlock
        exit $RET
}

d_stop() {
        lock
        log_daemon_msg "Stopping system $DAEMON_NAME daemon"
        start-stop-daemon --stop --quiet --oknodo --pidfile $PIDFILE --retry=TERM/3/KILL/3
        log_end_msg $?
        unlock
}

case "$1" in

        start|stop)
                d_${1}
                ;;

        restart|reload|force-reload)
                        d_stop
                        d_start
                ;;

        status)
                status_of_proc -p "$PIDFILE" "$DAEMON_EXEC" "$DAEMON_NAME" && exit 0 || exit $?
                ;;
        *)
                echo "Usage: /etc/init.d/$DAEMON_NAME {start|stop|force-stop|restart|reload|force-reload|status}"
                exit 1
                ;;
esac
exit 0
